# Generated by Django 4.1.5 on 2023-07-20 17:36

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("inventory", "0005_rename_ptao_account_alter_account_options_and_more"),
    ]

    operations = [
        migrations.RenameField(
            model_name="order",
            old_name="ptao",
            new_name="account",
        ),
    ]



# Generated by Django 4.1.5 on 2023-07-20 17:30

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("inventory", "0004_alter_category_id_alter_item_id_and_more"),
    ]

    operations = [
        migrations.RenameModel(
            old_name="PTAO",
            new_name="Account",
        ),
        migrations.AlterModelOptions(
            name="account",
            options={
                "ordering": ["code"],
                "verbose_name": "Account",
                "verbose_name_plural": "Accounts",
            },
        ),
        migrations.AlterModelOptions(
            name="order",
            options={"ordering": ["-created"]},
        ),
    ]



# -*- coding: utf-8 -*-
# -*- mode: python -*-
from django.contrib.auth.decorators import login_required
from django.urls import re_path

from inventory import views

app_name = "inventory"
urlpatterns = [
    re_path(r"^$", views.index, name="index"),
    re_path(r"^orders/$", views.OrderList.as_view(), name="orders"),
    re_path(
        r"^orders/new/$", login_required(views.OrderEntry.as_view()), name="new_order"
    ),
    re_path(r"^orders/(?P<pk>\d+)/$", views.OrderView.as_view(), name="order"),
    re_path(
        r"^orders/(?P<pk>\d+)/place/$",
        login_required(views.OrderMarkPlaced.as_view()),
        name="mark_order_placed",
    ),
    re_path(r"^items/$", views.ItemList.as_view(), name="items"),
    re_path(
        r"^items/new/$", login_required(views.ItemEntry.as_view()), name="new_item"
    ),
    re_path(r"^items/(?P<pk>\d+)/$", views.ItemView.as_view(), name="item"),
    re_path(
        r"^items/(?P<pk>\d+)/order/$",
        login_required(views.OrderItemEntry.as_view()),
        name="add_item_to_order",
    ),
    re_path(
        r"^orderitems/(?P<pk>\d+)/delete/$",
        login_required(views.OrderItemDelete.as_view()),
        name="remove_item_from_order",
    ),
]



# Generated by Django 4.1.5 on 2023-07-21 18:17
from django.db.models import Count
from django.db import migrations


def purge_duplicate_named(apps, schema_editor):
    for model_name in ("Category", "Manufacturer", "Unit", "Vendor"):
        field_name = model_name.lower()
        model = apps.get_model("inventory", model_name)
        duplicates = (
            model.objects.values("name").annotate(count=Count("id")).filter(count__gt=1)
        )
        for duplicate in duplicates:
            print(
                f"found {duplicate['count']} duplicates for {model_name} with name {duplicate['name']}"
            )
            keep, *destroy = model.objects.filter(name=duplicate["name"])
            for object in destroy:
                for item in object.item_set.all():
                    print(
                        f"{item}: reassigned {field_name} from {getattr(item, field_name)} to {keep}"
                    )
                    setattr(item, field_name, keep)
                    item.save()
                if object.item_set.count() == 0:
                    print(f"{object}: no more associated records; deleting")
                    object.delete()


def purge_duplicate_catalog(apps, schema_editor):
    Item = apps.get_model("inventory", "Item")
    duplicates = (
        Item.objects.values("vendor", "catalog")
        .annotate(count=Count("id"))
        .filter(count__gt=1)
    )
    for duplicate in duplicates:
        print(
            f"found {duplicate['count']} duplicates for Item with catalog {duplicate['catalog']} for vendor {duplicate['vendor']}"
        )
        keep, *destroy = Item.objects.filter(
            vendor=duplicate["vendor"], catalog=duplicate["catalog"]
        )
        for object in destroy:
            for orderitem in object.orderitem_set.all():
                print(f"{orderitem}: reassigned item from {orderitem.item} to {keep}")
                orderitem.item = keep
                orderitem.save()
            if object.item_set.count() == 0:
                print(f"{object}: no more associated records; deleting")
                object.delete()


class Migration(migrations.Migration):
    dependencies = [
        ("inventory", "0006_rename_ptao_order_account"),
    ]

    operations = [
        migrations.RunPython(purge_duplicate_named),
        migrations.RunPython(purge_duplicate_catalog),
    ]



# Generated by Django 4.1.5 on 2023-07-21 18:17
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("inventory", "0007_remove_duplicates"),
    ]

    operations = [
        migrations.AlterField(
            model_name="category",
            name="name",
            field=models.CharField(max_length=45, unique=True),
        ),
        migrations.AlterField(
            model_name="manufacturer",
            name="name",
            field=models.CharField(max_length=64, unique=True),
        ),
        migrations.AlterField(
            model_name="order",
            name="ordered",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="orderitem",
            name="reconciled",
            field=models.BooleanField(default=False),
        ),
        migrations.AlterField(
            model_name="unit",
            name="name",
            field=models.CharField(max_length=45, unique=True),
        ),
        migrations.AlterField(
            model_name="vendor",
            name="name",
            field=models.CharField(max_length=64, unique=True),
        ),
        migrations.AddConstraint(
            model_name="item",
            constraint=models.UniqueConstraint(
                fields=("vendor", "catalog"), name="unique_vendor_catalog_number"
            ),
        ),
    ]



# -*- coding: utf-8 -*-
from __future__ import unicode_literals

from django.db import models, migrations
from django.conf import settings
import datetime


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name='Category',
            fields=[
                ('id', models.AutoField(serialize=False, verbose_name='ID', primary_key=True, auto_created=True)),
                ('name', models.CharField(max_length=45)),
            ],
            options={
                'ordering': ['name'],
                'verbose_name_plural': 'categories',
            },
        ),
        migrations.CreateModel(
            name='Item',
            fields=[
                ('id', models.AutoField(serialize=False, verbose_name='ID', primary_key=True, auto_created=True)),
                ('name', models.CharField(max_length=128)),
                ('chem_formula', models.CharField(max_length=45, null=True, verbose_name='Chemical formula', blank=True)),
                ('catalog', models.CharField(max_length=45, null=True, verbose_name='Catalog number', blank=True)),
                ('manufacturer_number', models.CharField(max_length=45, null=True, blank=True)),
                ('size', models.DecimalField(max_digits=10, decimal_places=2, null=True, verbose_name='Size of unit', blank=True)),
                ('date_added', models.DateField(auto_now_add=True)),
                ('comments', models.TextField(blank=True)),
                ('category', models.ForeignKey(to='inventory.Category', on_delete=models.CASCADE)),
            ],
        ),
        migrations.CreateModel(
            name='Manufacturer',
            fields=[
                ('id', models.AutoField(serialize=False, verbose_name='ID', primary_key=True, auto_created=True)),
                ('name', models.CharField(max_length=64)),
                ('url', models.CharField(max_length=64, null=True, blank=True)),
                ('rep', models.CharField(max_length=45, null=True, blank=True)),
                ('rep_phone', models.CharField(max_length=16, null=True, blank=True)),
                ('support_phone', models.CharField(max_length=16, null=True, blank=True)),
            ],
            options={
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='Order',
            fields=[
                ('id', models.AutoField(serialize=False, verbose_name='ID', primary_key=True, auto_created=True)),
                ('name', models.CharField(max_length=64)),
                ('created', models.DateTimeField(auto_now_add=True)),
                ('ordered', models.BooleanField()),
                ('order_date', models.DateField(default=datetime.date.today)),
            ],
            options={
                'ordering': ['-order_date', 'name'],
            },
        ),
        migrations.CreateModel(
            name='OrderItem',
            fields=[
                ('id', models.AutoField(serialize=False, verbose_name='ID', primary_key=True, auto_created=True)),
                ('units_purchased', models.IntegerField()),
                ('cost', models.DecimalField(max_digits=10, decimal_places=2, null=True, verbose_name='Cost per unit', blank=True)),
                ('date_arrived', models.DateField(null=True, blank=True)),
                ('serial', models.CharField(max_length=45, null=True, verbose_name='Serial number', blank=True)),
                ('uva_equip', models.CharField(max_length=32, null=True, verbose_name='UVa equipment number', blank=True)),
                ('location', models.CharField(max_length=45, null=True, help_text='example: -80 freezer, refrigerator, Gilmer 283', blank=True)),
                ('expiry_years', models.DecimalField(max_digits=4, decimal_places=2, null=True, verbose_name='Warranty or Item expiration (y)', blank=True)),
                ('reconciled', models.BooleanField()),
                ('item', models.ForeignKey(to='inventory.Item', on_delete=models.CASCADE)),
                ('order', models.ForeignKey(to='inventory.Order', on_delete=models.CASCADE)),
            ],
            options={
                'db_table': 'inventory_order_items',
            },
        ),
        migrations.CreateModel(
            name='PTAO',
            fields=[
                ('id', models.AutoField(serialize=False, verbose_name='ID', primary_key=True, auto_created=True)),
                ('code', models.CharField(max_length=64, unique=True)),
                ('description', models.CharField(max_length=128)),
                ('expires', models.DateField(null=True, blank=True)),
            ],
            options={
                'ordering': ['code'],
                'verbose_name': 'PTAO',
                'verbose_name_plural': 'PTAOs',
            },
        ),
        migrations.CreateModel(
            name='Unit',
            fields=[
                ('id', models.AutoField(serialize=False, verbose_name='ID', primary_key=True, auto_created=True)),
                ('name', models.CharField(max_length=45)),
            ],
            options={
                'ordering': ['name'],
            },
        ),
        migrations.CreateModel(
            name='Vendor',
            fields=[
                ('id', models.AutoField(serialize=False, verbose_name='ID', primary_key=True, auto_created=True)),
                ('name', models.CharField(max_length=64)),
                ('url', models.CharField(max_length=64, null=True, blank=True)),
                ('phone', models.CharField(max_length=16, null=True, blank=True)),
                ('rep', models.CharField(max_length=45, null=True, blank=True)),
                ('rep_phone', models.CharField(max_length=16, null=True, blank=True)),
            ],
            options={
                'ordering': ['name'],
            },
        ),
        migrations.AddField(
            model_name='order',
            name='items',
            field=models.ManyToManyField(through='inventory.OrderItem', to='inventory.Item'),
        ),
        migrations.AddField(
            model_name='order',
            name='ordered_by',
            field=models.ForeignKey(to=settings.AUTH_USER_MODEL, on_delete=models.CASCADE),
        ),
        migrations.AddField(
            model_name='order',
            name='ptao',
            field=models.ForeignKey(blank=True, to='inventory.PTAO', null=True, on_delete=models.SET_NULL),
        ),
        migrations.AddField(
            model_name='item',
            name='manufacturer',
            field=models.ForeignKey(help_text='leave blank if unknown or same as vendor', blank=True,
                                    to='inventory.Manufacturer', null=True, on_delete=models.SET_NULL),
        ),
        migrations.AddField(
            model_name='item',
            name='parent_item',
            field=models.ForeignKey(help_text='example: for printer cartriges, select printer', blank=True,
                                    to='inventory.Item', null=True, on_delete=models.SET_NULL),
        ),
        migrations.AddField(
            model_name='item',
            name='unit',
            field=models.ForeignKey(to='inventory.Unit', on_delete=models.CASCADE),
        ),
        migrations.AddField(
            model_name='item',
            name='vendor',
            field=models.ForeignKey(to='inventory.Vendor', on_delete=models.CASCADE),
        ),
    ]



# Generated by Django 4.1.5 on 2023-01-20 21:11

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('inventory', '0003_add_vendor_email'),
    ]

    operations = [
        migrations.AlterField(
            model_name='category',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='item',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='manufacturer',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='order',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='orderitem',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='ptao',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='unit',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
        migrations.AlterField(
            model_name='vendor',
            name='id',
            field=models.AutoField(primary_key=True, serialize=False),
        ),
    ]
